@@ -8,14 +8,10 @@ set -e
 
 dbus_services_dir="$1"
 tracker_miner_services_dir="$2"
-have_tracker_miner_apps="$3"
-have_tracker_miner_fs="$4"
-have_tracker_miner_rss="$5"
+have_tracker_miner_fs="$3"
+have_tracker_miner_rss="$4"
 
 mkdir -p ${DESTDIR}/${tracker_miner_services_dir}
-if ([ "$have_tracker_miner_apps" = "true" ]); then
-  ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.Applications.service" "${DESTDIR}/${tracker_miner_services_dir}/"
-fi
 ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.Extract.service" "${DESTDIR}/${tracker_miner_services_dir}/"
 if ([ "$have_tracker_miner_fs" = "true" ]); then
   ln -sf "${dbus_services_dir}/org.freedesktop.Tracker1.Miner.Files.service" "${DESTDIR}/${tracker_miner_services_dir}/"
