@@ -19,7 +19,7 @@
  * Boston, MA  02110-1301, USA.
  */
 
-#include "config.h"
+#include "config-miners.h"
 
 #include <sys/mman.h>
 #include <sys/types.h>
